@@ -15,7 +15,7 @@ def init(args):
 
     if not os.path.exists(os.path.join(home_path, '.ssh')):
         print "Creating ~/.ssh path"
-        os.mkdir(os.path.join(home_path, '.ssh'), 700)
+        os.mkdir(os.path.join(home_path, '.ssh'), 0o700)
 
     # Create gitomatic path
     if not os.path.exists(os.path.join(home_path, '.gitomatic')):
